//
//	MiscValueConnectInspector.m -- an IBInspector that is used to connect
//                                     a MiscValueCell to an arbitrary object
//                                     as a generic delegate.
//		Written by David Fedchenko (c) 1994 by David Fedchenko.
//				Version 1.0.  All rights reserved.
//
//		This notice may not be removed from this source code.
//
//	This object is included in the MiscKit by permission from the author
//	and its use is governed by the MiscKit license, found in the file
//	"LICENSE.rtf" in the MiscKit distribution.  Please refer to that file
//	for a list of all applicable permissions and restrictions.
//	

#import "MiscValueConnectInspector.h"
#import "MiscValueField.subproj/MiscValueConnector.h"

@implementation MiscValueField (ConnectionsInspector)

-(const char *)getConnectInspectorClassName
    {
    NXEvent *ev = [NXApp currentEvent];

    if (ev->flags & NX_ALTERNATEMASK)
        {
	return [super getConnectInspectorClassName];
        }
    else
        {
	return "MiscValueConnectInspector";
        }
    }

@end

@implementation MiscValueCell (ConnectionsInspector)

-(const char *)getConnectInspectorClassName
    {
    NXEvent *ev = [NXApp currentEvent];

    if (ev->flags & NX_ALTERNATEMASK)
        {
	return [super getConnectInspectorClassName];
        }
    else
        {
	return "MiscValueConnectInspector";
        }
    }

@end

@implementation MiscValueConnectInspector

- init
    {
    char buf[MAXPATHLEN + 1];
    id bundle;
	
    [super init];
	
    bundle = [NXBundle bundleForClass:[MiscValueField class]];
    [bundle getPath:buf forResource:"MiscValueConnectInspector" ofType:"nib"];
    [NXApp loadNibFile:buf owner:self withNames:NO fromZone:[self zone]];
    
    return self;
    }

- ok:sender
    {
    [self findConnection];

    if ([sender tag] == 0)
        {
	idConnector = [[MiscValueConnector alloc] init];
	[idConnector setDestination:[NXApp connectDestination]];
	[idConnector setSource:object];
	[[NXApp activeDocument] addConnector:idConnector];
        }
    else if ([sender tag] ==1)
        {
	[[NXApp activeDocument] removeConnector:idConnector];
	[idConnector free];
	idConnector = 0;
        }

    [self revert:self];

    return [super ok:sender];
    }

- revert:sender
    {
    [self findConnection];

    if (idConnector)
        {
	[self setCName:[idConnector destination]];
	[idButton setTitle:"Disconnect"];
	[idButton setTag:1];
	[idButton setEnabled:YES];
	}
    else
        {
	if ([NXApp isConnecting])
	    {
	    [self setCName:[NXApp connectDestination]];
	    [idButton setTitle:"Connect"];
	    [idButton setTag:0];
	    [idButton setEnabled:YES];
	    }
	else
            {
	    [idClassName setStringValue:""];
	    [idButton setTitle:"No Selection"];
	    [idButton setEnabled:NO];
	    [idButton setTag:2];
	    }
	}
    
    if (sender == self)
	{
	return self;
	}
    else
	{
	return [super revert:sender];
	}
    }

- (BOOL)wantsButtons
    {
    return NO;
    }

- findConnection
    {
    id idList = [[List alloc] initCount:1];

    [[NXApp activeDocument] listConnectors:idList forSource:object
                            filterClass:[MiscValueConnector class]];

    if ([idList count] == 1)
        {
	idConnector = [idList objectAt:0];
	}
    else
        {
	idConnector = 0;
	}
    
    [idList free];

    return self;
    }

- showLine:sender
    {
    [self findConnection];

    if (idConnector)
        {
	[NXApp displayConnectionBetween:object and:[idConnector destination]];
	}
    
    return self;
    }

- setCName:anObject
    {
    [idClassName setStringValue:[[anObject class] name]];

    return self;
    }

@end
